@@ -1,4 +1,4 @@
-/* $Id: gdict-speller.c,v 1.2 2000/05/18 00:29:48 hovinen Exp $ */
+/* $Id: gdict-speller.c,v 1.3 2000/06/25 20:51:43 hovinen Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -44,6 +44,8 @@ enum {
 
 static gint gdict_speller_signals[LAST_SIGNAL] = { 0, 0, 0 };
 
+static GnomeDialogClass *parent_class;
+
 static void gdict_speller_init (GDictSpeller *speller);
 static void gdict_speller_class_init (GDictSpellerClass *class);
 
@@ -175,8 +177,8 @@ static void
 gdict_speller_class_init (GDictSpellerClass *class) {
     GtkObjectClass *object_class;
     
-    object_class = (GtkObjectClass *) class;
-    
+    object_class = GTK_OBJECT_CLASS (class);
+
     gdict_speller_signals[WORD_LOOKUP_START_SIGNAL] =
         gtk_signal_new ("word_lookup_start", GTK_RUN_FIRST, object_class->type,
                         GTK_SIGNAL_OFFSET (GDictSpellerClass, word_lookup_start),
@@ -201,8 +203,12 @@ gdict_speller_class_init (GDictSpellerClass *class) {
     gtk_object_class_add_signals (object_class, gdict_speller_signals,
                                   LAST_SIGNAL);
     
+    parent_class = gtk_type_class (gnome_dialog_get_type ());
+
     class->word_lookup_done = NULL;
     class->word_not_found = NULL;
+
+    object_class->destroy = (void (*) (GtkObject *)) gdict_speller_destroy;
 }
 
 /* gdict_speller_new
@@ -234,6 +240,7 @@ gdict_speller_destroy (GDictSpeller *speller) {
     g_free (speller->database);
     dict_command_destroy (speller->get_strat_cmd);
     dict_command_destroy (speller->spell_cmd);
+    GTK_OBJECT_CLASS (parent_class)->destroy (GTK_OBJECT (speller));
 }
 
 /* gdict_speller_lookup
@@ -478,6 +485,7 @@ spell_word_data_cb (dict_command_t *command, dict_res_t *res, gpointer data) {
     GDictSpeller *speller;
     
     speller = GDICT_SPELLER (data);
+    if (!GTK_WIDGET_VISIBLE (GTK_WIDGET (speller))) return;
     speller_add_word (speller, res->desc);
 }
 
@@ -491,6 +499,7 @@ spell_strat_data_cb (dict_command_t *command, dict_res_t *res, gpointer data) {
     GDictSpeller *speller;
     
     speller = GDICT_SPELLER (data);
+    if (!GTK_WIDGET_VISIBLE (GTK_WIDGET (speller))) return;
     speller_add_strat (speller, res->name, res->desc);
 }
 
@@ -506,6 +515,8 @@ spell_word_status_cb (dict_command_t *command, DictStatusCode code,
     GDictSpeller *speller;
     
     speller = GDICT_SPELLER (data);
+
+    if (!GTK_WIDGET_VISIBLE (GTK_WIDGET (speller))) return;
     
     if (code == DICT_STATUS_OK)
       gtk_signal_emit (GTK_OBJECT (speller), 
@@ -529,6 +540,8 @@ spell_strat_status_cb (dict_command_t *command, DictStatusCode code,
     
     speller = GDICT_SPELLER (data);
     
+    if (!GTK_WIDGET_VISIBLE (GTK_WIDGET (speller))) return;
+
     if (code == DICT_STATUS_OK) {
         speller->strat_sel = GTK_OPTION_MENU (gtk_option_menu_new ());
         gtk_option_menu_set_menu (speller->strat_sel, 
