@@ -22,14 +22,13 @@
     ---------------------------------------------------------------------- */
 
 
+#include <config.h>
 #include <unistd.h>
 #include <time.h>
-#include <config.h>
 #include <sys/stat.h>
 #include "gtk/gtk.h"
 #include "logview.h"
-#include "gnome.h"
-#include "log.xpm"
+#include <gnome.h>
 #include <libgnomeui/gnome-window-icon.h>
 
 /*
@@ -39,7 +38,7 @@
  */
 
 void repaint (GtkWidget * canvas, GdkRectangle * area);
-void CreateMainWin ();
+void CreateMainWin (void);
 void log_repaint (GtkWidget * canvas, GdkRectangle * area);
 void PointerMoved (GtkWidget * canvas, GdkEventMotion * event);
 void HandleLogKeyboard (GtkWidget * win, GdkEventKey * event_key);
@@ -53,19 +52,21 @@ void MonitorMenu (GtkWidget* widget, gpointer user_data);
 void create_zoom_view (GtkWidget * widget, gpointer user_data);
 void UserPrefsDialog(GtkWidget * widget, gpointer user_data);
 void AboutShowWindow (GtkWidget* widget, gpointer user_data);
-void CloseApp ();
+void CloseApp (void);
 void CloseLog (Log *);
-void ShowErrMessage (char *);
+void FileSelectCancel (GtkWidget * w, GtkFileSelection * fs);
+void FileSelectOk (GtkWidget * w, GtkFileSelection * fs);
 void MainWinScrolled (GtkAdjustment *adjustment, GtkRange *);
 void CanvasResized (GtkWidget *widget, GtkAllocation *allocation);
 void ScrollWin (GtkRange *range, gpointer event);
 void LogInfo (GtkWidget * widget, gpointer user_data);
-void UpdateStatusArea ();
+void UpdateStatusArea (void);
 void set_scrollbar_size (int);
 void change_log (int dir);
-void open_databases ();
-int InitApp ();
-int InitPages ();
+void open_databases (void);
+void destroy (void);
+void InitApp (void);
+int InitPages (void);
 int RepaintLogInfo (GtkWidget * widget, GdkEventExpose * event);
 int read_regexp_db (char *filename, GList **db);
 int read_actions_db (char *filename, GList **db);
@@ -119,6 +120,7 @@ GnomeUIInfo view_menu[] = {
         {GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL}
 };
 
+#if 0
 GnomeUIInfo filter_menu[] = {
         {GNOME_APP_UI_ITEM, N_("Select...               "), 
 	 N_("Select log events"), StubCall, NULL, NULL,
@@ -128,6 +130,7 @@ GnomeUIInfo filter_menu[] = {
          GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
         {GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL}
 };
+#endif
 
 GnomeUIInfo help_menu[] = {
         {GNOME_APP_UI_ITEM, N_("About..                "), 
@@ -140,8 +143,8 @@ GnomeUIInfo help_menu[] = {
 GnomeUIInfo main_menu[] = {
 	GNOMEUIINFO_MENU_FILE_TREE(file_menu),
 	GNOMEUIINFO_MENU_VIEW_TREE(view_menu),
-        {GNOME_APP_UI_SUBTREE, N_("F_ilter"), NULL,  filter_menu, NULL, NULL,
-         GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
+/*        {GNOME_APP_UI_SUBTREE, N_("F_ilter"), NULL,  filter_menu, NULL, NULL, */
+/*         GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL}, */
 	GNOMEUIINFO_MENU_HELP_TREE(help_menu),
         {GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL}
 };
@@ -154,7 +157,7 @@ GnomeUIInfo main_menu[] = {
  */
 
 
-GtkWidget *app;
+GtkWidget *app = NULL;
 GtkWidget *main_win_scrollbar;
 GtkLabel *filename_label, *date_label;
 
@@ -162,7 +165,7 @@ GList *regexp_db, *descript_db, *actions_db;
 UserPrefsStruct *user_prefs;
 UserPrefsStruct user_prefs_struct;
 ConfigData *cfg;
-int open_log_visible;
+GtkWidget *open_file_dialog = NULL;
 
 extern GdkGC *gc;
 extern Log *curlog, *loglist[];
@@ -170,9 +173,6 @@ extern int numlogs, curlognum;
 extern int loginfovisible, calendarvisible;
 extern int cursor_visible;
 
-static gint init_timer = -1;
-
-
 /* ----------------------------------------------------------------------
    NAME:          destroy
    DESCRIPTION:   Exit program.
@@ -181,7 +181,7 @@ static gint init_timer = -1;
 void
 destroy (void)
 {
-   CloseApp (0);
+   CloseApp ();
 }
 
 /* ----------------------------------------------------------------------
@@ -195,6 +195,8 @@ main (int argc, char *argv[])
   bindtextdomain (PACKAGE, GNOMELOCALEDIR);
   textdomain (PACKAGE);
 
+  QueueErrMessages (TRUE);
+
   /*  Initialize gnome & gtk */
   gnome_init ("logview", VERSION, argc, argv);
 
@@ -206,13 +208,14 @@ main (int argc, char *argv[])
   /*  Show about window */
   /* AboutShowWindow (NULL, NULL); */
 
-  /*  Add a timer that will start initialization after */
-  /*  after the title window appears. */
-  init_timer = gtk_timeout_add (1000, (GtkFunction) InitApp, NULL);
+  InitApp ();
+
+  QueueErrMessages (FALSE);
+  ShowQueuedErrMessages ();
    
   /*  Loop application */
   gtk_main ();
-  
+
   return 0;
 }
 
@@ -221,7 +224,7 @@ main (int argc, char *argv[])
    DESCRIPTION: Main initialization routine.
    ---------------------------------------------------------------------- */
 
-int
+void
 InitApp ()
 {
   /*  Initialize variables */
@@ -239,10 +242,6 @@ InitApp ()
 
   /*  Display main window */
   CreateMainWin ();
-
-  /*  Remove timer by returning FALSE */
-  return FALSE;
-
 }
 
 /* ----------------------------------------------------------------------
@@ -258,8 +257,6 @@ CreateMainWin ()
    GtkWidget *frame, *padding;
    GtkLabel *label;
    GtkObject *adj;
-   GdkPixmap *icon_pixmap;
-   GdkBitmap *icon_bitmap;
    GtkAllocation req_size;
 
    /* Create App */
@@ -287,9 +284,10 @@ CreateMainWin ()
    gtk_widget_set_state (file_menu[1].widget, GTK_STATE_INSENSITIVE);
    if (numlogs < 2)
      gtk_widget_set_state (file_menu[3].widget, GTK_STATE_INSENSITIVE);
+#if 0
    gtk_widget_set_state (filter_menu[0].widget, GTK_STATE_INSENSITIVE);
    gtk_widget_set_state (filter_menu[1].widget, GTK_STATE_INSENSITIVE);
-
+#endif
 
    /* Create main canvas and scroll bar */
    frame = gtk_frame_new (NULL);
@@ -590,18 +588,6 @@ change_log_menu (GtkWidget * widget, gpointer user_data)
   change_log (1);
 }
 
-/* ----------------------------------------------------------------------
-   NAME:          FileSelectCancel
-   DESCRIPTION:   User selected a file.
-   ---------------------------------------------------------------------- */
-
-void
-FileSelectCancel (GtkWidget * w, GtkFileSelection * fs)
-{
-   gtk_widget_destroy (GTK_WIDGET (fs));
-   open_log_visible = FALSE;
-}
-
 /* ----------------------------------------------------------------------
    NAME:          FileSelectOk
    DESCRIPTION:   User selected a file.
@@ -610,7 +596,7 @@ FileSelectCancel (GtkWidget * w, GtkFileSelection * fs)
 void
 FileSelectOk (GtkWidget * w, GtkFileSelection * fs)
 {
-   char f[255];
+   char *f;
    Log *tl;
 
    /* Check that we haven't opened all logfiles allowed    */
@@ -620,12 +606,10 @@ FileSelectOk (GtkWidget * w, GtkFileSelection * fs)
        return;
      }
 
-   strncpy(f, gtk_file_selection_get_filename (GTK_FILE_SELECTION (fs)), 254);
-   f[254] = '\0';
+   f = g_strdup (gtk_file_selection_get_filename (GTK_FILE_SELECTION (fs)));
    gtk_widget_destroy (GTK_WIDGET (fs));
 
-   open_log_visible = FALSE;
-   if (f != NULL)
+   if (f != NULL) {
       if ((tl = OpenLogFile (f)) != NULL)
       {
 	 curlog = tl;
@@ -646,6 +630,8 @@ FileSelectOk (GtkWidget * w, GtkFileSelection * fs)
 	 if (numlogs >= 2)
 	   gtk_widget_set_sensitive (file_menu[3].widget, TRUE);
       }
+   }
+   g_free (f);
 
 }
 
@@ -665,11 +651,15 @@ LoadLogMenu (GtkWidget * widget, gpointer user_data)
    
    /*  Cannot have more than one fileselect window */
    /*  at one time. */
-   if (open_log_visible)
-     return;
+   if (open_file_dialog != NULL) {
+	   gtk_widget_show_now (open_file_dialog);
+	   gdk_window_raise (open_file_dialog->window);
+	   return;
+   }
 
 
    filesel = gtk_file_selection_new (_("Open new logfile"));
+   gtk_window_set_transient_for (GTK_WINDOW (filesel), GTK_WINDOW (app));
    gnome_window_icon_set_from_default (GTK_WINDOW (filesel));
 
    /* Make window modal */
@@ -682,15 +672,16 @@ LoadLogMenu (GtkWidget * widget, gpointer user_data)
 		       "clicked", (GtkSignalFunc) FileSelectOk,
 		       filesel);
    gtk_signal_connect_object (GTK_OBJECT (GTK_FILE_SELECTION (filesel)->cancel_button),
-			      "clicked", (GtkSignalFunc) FileSelectCancel,
+			      "clicked", (GtkSignalFunc) gtk_widget_destroy,
 			      GTK_OBJECT (filesel));
 
-   if (!GTK_WIDGET_VISIBLE (filesel))
-      gtk_widget_show (filesel);
-   else
-      gtk_widget_destroy (filesel);
+   gtk_signal_connect (GTK_OBJECT (filesel),
+		       "destroy", (GtkSignalFunc) gtk_widget_destroy,
+		       &open_file_dialog);
 
-   open_log_visible = TRUE;
+   gtk_widget_show (filesel);
+
+   open_file_dialog = filesel;
 }
 
 
@@ -714,7 +705,7 @@ ExitProg (GtkWidget * widget, gpointer user_data)
    ---------------------------------------------------------------------- */
 
 void 
-CloseApp ()
+CloseApp (void)
 {
    int i;
 
@@ -731,7 +722,7 @@ CloseApp ()
    ---------------------------------------------------------------------- */
 
 void
-open_databases ()
+open_databases (void)
 {
   char full_name[255];
   int found;
